CREATE OR REPLACE TRIGGER maxdata.tr_lv7loc_bef_d
BEFORE DELETE ON maxdata.lv7loc
REFERENCING NEW AS NEW OLD AS OLD
FOR EACH ROW

/*
---------------------------------------------------------------------------------------------------
Revision 2.1.0.0  2012/07/09 for S0824486
moved deleting of temp lv9mast records to RSM Server startup

Revision 1.1.2.3  2009/09/22 14:30:09  makirk
Undoing change for S0476933 as per GC.  Oracle trigger does not need fix.

Revision 1.1.2.1  2009/05/06 20:16:44  makirk
Initial porting from space optm
---------------------------------------------------------------------------------------------------
*/

-- "FOR EACH ROW" will fire for each row affected so this can replace the cursor used in the SS version

DECLARE
t_cnt           PLS_INTEGER;
n_sqlnum        PLS_INTEGER;
t_error_msg     VARCHAR2(255);

BEGIN
n_sqlnum := 1100;
IF NVL(:OLD.lv1loc_id,0) <> -2 THEN
BEGIN
        -- Checking if the table auto_segment exists first (for databases that don't have automation yet)
        t_cnt := 0;

        n_sqlnum := 1200;
        SELECT COUNT(*)
          INTO t_cnt
          FROM user_tables
         WHERE table_name = 'AUTO_SEGMENT';

        IF (t_cnt = 1) THEN
                n_sqlnum := 1300;

                DELETE FROM maxdata.auto_segment
                 WHERE lv7loc_id = :OLD.lv7loc_id
                   AND :OLD.record_type IN ('M','T','C','D');
        END IF;

END; -- Delete trigger on lv7loc
END IF;

EXCEPTION
   WHEN OTHERS THEN
        t_error_msg := SQLERRM;
        maxdata.p_log ('tr_lv7loc_aft_d', 'error', t_error_msg, NULL, n_sqlnum);
        RAISE_APPLICATION_ERROR(-20001,t_error_msg);
        RETURN;
END tr_lv7loc_aft_d;
/